import requests
import json


class Botlists:
    def __init__(self, api_key: str):
        if type(api_key) is not str:
            raise ValueError(f"please enter a string as param, you entered {type(api_key)}")
        self.url = 'https://botlists.com/api/bot'
        self.api_key = api_key

    def get(self):
        r = requests.get(self.url, headers={"token": self.api_key})
        return r.content

    def count(self, server_count: int):
        if type(server_count) is not int:
            raise ValueError(f"please enter a number as param, you entered {type(server_count)}")
        body = {"guild_count": server_count}
        r = requests.post(self.url, data=json.dumps(body), headers={"token": self.api_key, "Content-Type": "application/json"})
        return r.content



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='ablpywrapper',
    version='0.0.2',
    description='Astro botlist python api wrapper',
    py_modules=["main"],
    package_dir={'': 'src'},
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Operating System :: OS Independent"
    ],
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=[
      "requests"
    ],
    extras_require={
        "dev": [
            "pytest>=3.7"
        ]
    },
    url="https://github.com/botlists/ablpywrapper",
    author="Sell"
)
